@@ -14,7 +14,7 @@ use Wikibase::Datatype::Struct::Value::Monolingual;
 
 Readonly::Array our @EXPORT_OK => qw(obj2struct struct2obj);
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 sub obj2struct {
 	my ($obj, $base_uri) = @_;
@@ -218,6 +218,9 @@ Returns Wikibase::Datatype::Item instance.
          Object doesn't exist.
          Object isn't 'Wikibase::Datatype::Item'.
 
+ struct2obj():
+         Structure isn't for 'item' type.
+
 =head1 EXAMPLE1
 
  use strict;
@@ -822,12 +825,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2020
+© Michal Josef Špaček 2020-2021
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
