@@ -13,7 +13,7 @@ use Wikibase::Datatype::Struct::Utils qw(obj_array_ref2struct struct2snaks_array
 
 Readonly::Array our @EXPORT_OK => qw(obj2struct struct2obj);
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 sub obj2struct {
 	my ($obj, $base_uri) = @_;
@@ -437,12 +437,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2020
+© Michal Josef Špaček 2020-2021
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
