@@ -3,15 +3,15 @@
 use strict;
 use warnings;
 
-use Wikibase::Datatype::Struct::Value::Item qw(struct2obj);
+use Wikibase::Datatype::Struct::Value::Property qw(struct2obj);
 
-# Item structure.
+# Property structure.
 my $struct_hr = {
         'type' => 'wikibase-entityid',
         'value' => {
-                'entity-type' => 'item',
-                'id' => 'Q123',
-                'numberic-id' => 123,
+                'entity-type' => 'property',
+                'id' => 'P123',
+                'numeric-id' => 123,
         },
 };
 
@@ -29,5 +29,5 @@ print "Type: $type\n";
 print "Value: $value\n";
 
 # Output:
-# Type: item
-# Value: Q123
\ No newline at end of file
+# Type: property
+# Value: P123
\ No newline at end of file
